@@ -83,9 +83,11 @@ export class Test implements LimeWebComponent {
 
         return (
             <div class="container">
+                <limel-config config={{iconPath: '/static/limepkg_scrive/static/'}} />
                 <limel-button
                     label={label}
                     outlined={true}
+                    icon="scrive"
                     onClick={() =>
                         this.goToScrive(this.context.id)
                     }
